#[non_exhaustive]pub enum JournalError {
Io {
message: String,
path: Option<PathBuf>,
},
CorruptEntry {
sequence: u64,
expected_crc: u32,
actual_crc: u32,
},
DeserializationError {
sequence: u64,
message: String,
},
SerializationError {
message: String,
},
EntryTooLarge {
entry_bytes: usize,
segment_size: usize,
},
InvalidDirectory {
path: PathBuf,
},
MutexPoisoned,
SequenceNotFound {
sequence: u64,
},
InvalidEntryHeader {
offset: usize,
message: String,
},
}Expand description
Errors that can occur within the journal subsystem.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
An I/O error occurred while reading or writing journal files.
Fields
CorruptEntry
A journal entry failed CRC32 integrity verification.
Fields
DeserializationError
The journal entry payload could not be deserialized.
Fields
SerializationError
The journal entry payload could not be serialized.
EntryTooLarge
A segment file is too small to hold the entry being appended.
Fields
InvalidDirectory
The journal directory does not exist or is not accessible.
MutexPoisoned
An internal mutex was poisoned (another thread panicked while holding the lock).
SequenceNotFound
The requested sequence number was not found in the journal.
InvalidEntryHeader
The journal entry has an invalid header (truncated or malformed).